@@ -78,7 +78,11 @@ void TrackView::setupMenubar()
 
     connect(m_pSortByAct,SIGNAL(selectionChanged(int)),SLOT(OnSortingSelectionChanged(int)));
     menuBar()->addAction(m_pSortByAct);
+
+#ifdef Q_WS_MAEMO_5
     menuBar()->addAction(tr("FM Transmitter"));
+#endif
+
     connect(menuBar(),SIGNAL(triggered(QAction*)),SLOT(OnMenubarAction(QAction*)));
  }
 
@@ -116,8 +120,13 @@ void TrackView::OnPlayAlbumAction()
             if(m_pSession->browse(track->getAlbum(),&m_CallerID)) //request to load album tracks (browse album)
             {
                 m_pTrackListView->setDisabled(true);
+#ifdef Q_WS_MAEMO_5
                 QMaemo5InformationBox::information(this,tr("Loading album tracks"));
                 setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true);
+#else
+                Banner::information(this,tr("Loading album tracks"));
+#endif
+
             }
         }
     }
@@ -152,20 +161,31 @@ void TrackView::OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 caller
             if(error.isError())
             {
                 //error occured (album browse request failed)
+#ifdef Q_WS_MAEMO_5
                 QMaemo5InformationBox::information(this,tr("Fetching of album tracks failed: ") + error.toString());
+#else
+                Banner::information(this,tr("Fetching of album tracks failed: ") + error.toString());
+#endif
+
             }
             else
             {
                 if(!browser->load())
                 {
+#ifdef Q_WS_MAEMO_5
                     QMaemo5InformationBox::information(this,tr("Failed to load tracks!"));
+#else
+                    Banner::information(this,tr("Failed to load tracks!"));
+#endif
                 }
                 browser->sortByDiscIndex(); //sort tracks in album order
                 emit playQueueSet(browser->getTracks(false),0); //only add available (playable) album tracks to the playqueue
             }
         }
     }
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
+#endif
     m_pTrackListView->setDisabled(false);
 }
 
@@ -292,9 +312,13 @@ void TrackView::OnTrackActivated(QModelIndex trackIndex)
     if(m_lastTimeTrackActivated.restart()>=700) //ignore successive (rapid) activations (within 700msecs since last activation)
     {
         m_pTrackListView->setEnabled(false); //disable table temporarily
+#ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+#endif
         setPlayQueue();
+#ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+#endif
         m_pTrackListView->setEnabled(true); //re-enable the list view
     }
 }
@@ -330,7 +354,9 @@ void TrackView::addTracks(Spotify::Playlist* playlist)
 {
     //add playlist tracks to main listview
 
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+#endif
 
     m_pTrackListModel->clear();
 
@@ -355,8 +381,9 @@ void TrackView::addTracks(Spotify::Playlist* playlist)
         QModelIndex index = m_pTrackListModel->index(-1,-1);
         m_pTrackListView->setCurrentIndex(index);
     }
-
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
+#endif
 }
 
 void TrackView::addTrackListModelItem(Spotify::Track* track, int pos)
@@ -398,7 +425,9 @@ void TrackView::addTracks(const QList<Spotify::Track*>& trackList)
 
     qint32 pos = 0;
 
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+#endif
 
     m_pTrackListModel->clear();
 
@@ -421,8 +450,9 @@ void TrackView::addTracks(const QList<Spotify::Track*>& trackList)
          QModelIndex index = m_pTrackListModel->index(-1,-1);
          m_pTrackListView->setCurrentIndex(index);
      }
-
+#ifdef Q_WS_MAEMO_5
      setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
+#endif
 }
 
 void TrackView::keyPressEvent(QKeyEvent *evt)
