@@ -63,8 +63,8 @@ MainWindow::MainWindow(QWidget *parent)
 
     m_pHelpViewer = new HelpViewer(this); //allocate online help instance
 
-    m_pLoginDlg = new LoginDialog(m_pAppSettings, this); //allocate login dialog instance
-    connect(m_pLoginDlg,SIGNAL(doSpotifyLogin(const QString&, const QString&)),SLOT(OnSpotifyLogin(const QString&, const QString&)));
+    m_pLoginDlg = new LoginDialog(m_pSession, m_pAppSettings, this); //allocate login dialog instance
+    connect(m_pLoginDlg,SIGNAL(doSpotifyLogin(const QString&, const QString&, bool)),SLOT(OnSpotifyLogin(const QString&, const QString&, bool)));
     m_pSettingsDlg = new SettingsDialog(m_pAppSettings, this); //allocate settings dialog instance
 
     //set up the the main window menu
@@ -74,6 +74,7 @@ MainWindow::MainWindow(QWidget *parent)
 #endif
     menuBar()->addAction(tr("Online Help"));
     menuBar()->addAction(tr("About"));
+    menuBar()->addAction(tr("Log Out"));
 
     //setup the app About dialog box
     initAboutDialog();
@@ -113,7 +114,7 @@ MainWindow::MainWindow(QWidget *parent)
 
     connect(m_pLoginDlg,SIGNAL(rejected()),SLOT(OnLoginDialogRejected()));
     connect(m_pSettingsDlg,SIGNAL(settingsSaved()),SLOT(OnSettingsSaved()));
-    connect(m_pSession,SIGNAL(loggedIn(Spotify::Error)),SLOT(OnLoggedIn(Spotify::Error)));
+    connect(m_pSession,SIGNAL(loggedIn(Spotify::Error)),SLOT(OnLoginResponse(Spotify::Error)));
     connect(m_pSession,SIGNAL(loggedOut()),SLOT(OnLoggedOut()));
     connect(m_pSession,SIGNAL(playlistContainersReady(QList<Spotify::Playlist*>)),this,SLOT(OnPlaylistContainersReady(QList<Spotify::Playlist*>)));
     connect(m_pSession,SIGNAL(playing(bool)),SLOT(OnPlayingState(bool)));
@@ -179,24 +180,15 @@ MainWindow::MainWindow(QWidget *parent)
     emit handleLoginType(); //check whether we should login directly, or allow user to enter login credentials (display login dialog accordingly)
 }
 
-void MainWindow::OnSpotifyLogin(const QString& strUserID, const QString& strPassword)
+void MainWindow::OnSpotifyLogin(const QString& strUserID, const QString& strPassword, bool saveCredentials)
 {
     //Sends of actual login req. to Spotify service backend. Inits app network session if necessary.
-    Spotify::Error err;
-    sp_bitrate selectedBitrate;
+
+    Spotify::Error error;
 
     if(!m_SessionInit)
     {//session not initialised; init session
-        //read preferred bitrate from settings file
-        int prefBitrate = m_pAppSettings->value("QSpot/PrefBitrate",IDX_BITRATE_160k).toInt();
-        if(prefBitrate==IDX_BITRATE_96k)
-            selectedBitrate = SP_BITRATE_96k;
-        else if(prefBitrate==IDX_BITRATE_320k)
-            selectedBitrate = SP_BITRATE_320k;
-        else //default bitrate
-            selectedBitrate = SP_BITRATE_160k;
-
-        m_pSession->init(selectedBitrate); //init new session prior to login
+        m_pSession->init(); //init new session prior to login
         m_SessionInit = true;
     }
 
@@ -204,21 +196,11 @@ void MainWindow::OnSpotifyLogin(const QString& strUserID, const QString& strPass
     {
         if(strUserID!="")
         {//use credentials supplied via login dialog (manual login)
-            err = m_pSession->login(strUserID,strPassword);
+            m_pSession->login(strUserID,strPassword,saveCredentials);
         }
         else
-        { //use credentials from settings (automatic login)
-            err = m_pSession->login(m_pAppSettings->value("QSpot/UserID").toString(),m_pAppSettings->value("QSpot/Password").toString());
-        }
-        if(err.isError())
-        {
-#ifdef Q_WS_MAEMO_5
-            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
-            QMaemo5InformationBox::information(this,tr("Error:") + " " + err.toString());
-#else
-            Banner::information(this,tr("Error:") + " " + err.toString());
-#endif
-            emit showLogin(); //emit signal requesting to show login dialog
+        { //try to use remembered credentials (automatic login)
+            m_pSession->login(m_pAppSettings->value("QSpot/UserID","").toString(),m_pAppSettings->value("QSpot/Password","").toString());
         }
     }
     else
@@ -249,7 +231,7 @@ void MainWindow::OnHandleLoginType()
 #ifdef Q_WS_MAEMO_5
          setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
 #endif
-        OnSpotifyLogin("","");
+        OnSpotifyLogin("","",true);
     }
     else
     {
@@ -269,9 +251,10 @@ void MainWindow::initAboutDialog()
 {
     //init the application about dialog
 
-    m_AboutDlg.setWindowTitle(tr("About QSpot"));
-    m_AboutDlg.setIcon("/usr/share/icons/hicolor/64x64/apps/qspot.png");
-    m_AboutDlg.setText(tr("QSpot version ") + APP_VERSION + "\n\n" + tr("An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).\n\n"
+    m_AboutDlg.setWindowTitle(tr("About QSpot") + " " + QString(APP_VERSION));
+    m_AboutDlg.setTopIcon("/usr/share/icons/hicolor/64x64/apps/qspot.png");
+    m_AboutDlg.setBottomIcon("/opt/qspot/images/spotify-core-logo.png"); //powered by Spotify(R) Core
+    m_AboutDlg.setText(tr("An open-source Qt-based Spotify client for the N900/Maemo5.\n"
                         "(C) 2011 Andreas Enbacka and The QSpot Team.\n\n"
                         "Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, "
                         "and to Tomi (rantom@tmo), Florian (florian@tmo) and Benno (bartus@tmo) for the translations."));
@@ -313,7 +296,12 @@ void MainWindow::OnDisplayFMTransmitterDialog()
 void MainWindow::OnSettingsSaved()
 {
     //called when app settings have been saved (modified)  
+    updateSettings();
+}
 
+void MainWindow::updateSettings()
+{
+   //update / set application-related settings
     //buffering related settings
     m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
 
@@ -326,19 +314,6 @@ void MainWindow::OnSettingsSaved()
         m_pSession->setPreBufferingActive(false);
     }
 
-    if(m_pAppSettings->value("QSpot/SaveCredentials",SAVE_CREDENTIALS_DEFAULT).toInt())
-    { //current session username and password should be saved to the settings file
-        m_pAppSettings->setValue("QSpot/UserID",m_pSession->getUserID()); //session UserID
-        m_pAppSettings->setValue("QSpot/Password",m_pSession->getUserPwd()); //session user password
-    }
-    else
-    {
-        //no settings should be saved, clear data in case previously set
-        m_pAppSettings->setValue("QSpot/UserID","");
-        m_pAppSettings->setValue("QSpot/Password","");
-    }
-
-
     //display orientation setting
     setDisplayOrientation(m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt());
 
@@ -365,6 +340,17 @@ void MainWindow::OnSettingsSaved()
     {
          m_pQueueView->setHideCoverart(false);
     }
+
+    //set preferred bitrate
+    sp_bitrate selectedBitrate;
+    int prefBitrate = m_pAppSettings->value("QSpot/PrefBitrate",IDX_BITRATE_160k).toInt();
+    if(prefBitrate==IDX_BITRATE_96k)
+        selectedBitrate = SP_BITRATE_96k;
+    else if(prefBitrate==IDX_BITRATE_320k)
+        selectedBitrate = SP_BITRATE_320k;
+    else //default bitrate
+        selectedBitrate = SP_BITRATE_160k;
+    m_pSession->setPreferredBitrate((selectedBitrate));
 }
 
 void MainWindow::OnShowLogin()
@@ -477,7 +463,6 @@ void MainWindow::OnShowArtistView(Spotify::Artist* pArtist)
 
 void MainWindow::OnPlayQueuePosUpdated(qint32 pos)
 {
-
     if(pos>=0)
     {
         m_currQueuePos = pos;
@@ -503,23 +488,28 @@ void MainWindow::OnPlayQueuePosUpdated(qint32 pos)
 }
 
 void MainWindow::logout()
-{
-  //logout the current user and display the login dialog
-  m_pSession->logout();
-  close();
+{//logout the curent user and display the login dialog
+    //clear saved credentials
+    m_pAppSettings->setValue("QSpot/SaveCredentials",0);
+    m_pAppSettings->setValue("QSpot/UserID","");
+    m_pAppSettings->setValue("QSpot/Password","");
+    close(); //close application
+}
+
+void MainWindow::closeEvent(QCloseEvent *)
+{//event received upon application shutdown
+    m_pSession->logout(); //logout current user
 }
 
 void MainWindow::OnLoginDialogRejected()
-{
-//request to reject the login dialog, exit app
+{//request to reject the login dialog, exit app
     qApp->quit();
 }
 
-void MainWindow::OnLoggedIn(Spotify::Error error)
+void MainWindow::OnLoginResponse(Spotify::Error error)
 {
-    //Slot invoked when response from login request received (from Spotify service backend)
-
-    if(error.isError())
+    //Slot invoked when response from login request received (from Spotify library)
+    if(error.isError()) //some error occured during login
     {
 #ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide main window progress indicator
@@ -542,6 +532,12 @@ void MainWindow::OnLoggedIn(Spotify::Error error)
         m_pReconnectTimer->stop(); //stop reconnect timer in case it is active
         if(!m_reConnectReq) // do not reload playlist metadata on re-connect request
         {
+            if(m_pLoginDlg->getSaveCredentials())
+            {//user credentials should be stored (for automatic re-login)
+                m_pAppSettings->setValue("QSpot/SaveCredentials",1);
+                m_pAppSettings->setValue("QSpot/UserID",m_pSession->getRememberedUser());
+                m_pAppSettings->setValue("QSpot/Password",m_pSession->getUserPwd());
+            }
     #ifdef Q_WS_MAEMO_5
             m_pLoginDlg->setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display main window progress indicator
@@ -589,19 +585,8 @@ void MainWindow::OnPlaylistLoadingTimeout()
 void MainWindow::OnReconnectTimeout()
 {
     //triggered by timer when automatic (timed) reconnect request should be performed (triggered once a minute)
-    Spotify::Error err = m_pSession->reconnect(); //try to re-connect to Spotify using current session credentials
-    if(err.isError())
-    {//some error occured
-#ifdef Q_WS_MAEMO_5
-        QMaemo5InformationBox::information(this,tr("Failed to re-authenticate with Spotify"));
-#else
-        Banner::information(this,tr("Failed to re-authenticate with Spotify"));
-#endif
-    }
-    else
-    {
-        m_pReconnectTimer->stop(); //stop the timer
-    }
+    m_pSession->relogin(); //try to re-connect to Spotify using current session credentials
+    m_pReconnectTimer->stop(); //stop the timer
 }
 
 void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
@@ -653,31 +638,7 @@ void MainWindow::setupInitialState()
     m_SearchInput.setFocus(); //set initial (default) focus to the Search input field
     m_SearchBtn.setDisabled(false);
 
-    //headset related settings
-    if(m_pAppSettings->value("QSpot/pauseOnHsetUnplugged",PAUSE_ON_HEADSET_UNPLUG_DEFAULT).toInt())
-        m_pQueueView->setPauseOnHSUnplugged(true);
-    else
-        m_pQueueView->setPauseOnHSUnplugged(false);
-
-    //scrobbling settings
-    m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
-    if(m_pAppSettings->value("QSpot/enableScrobbling",ENABLE_SCROBBLING_DEFAULT).toInt())
-    {
-        //scrobbling enabled, authenticate user to retrieve session key
-        m_pLastFMScrobbler->setCache(true); //enable caching of scrobbles
-        m_pLastFMScrobbler->authenticateSession(m_pAppSettings->value("QSpot/lastfmUid","").toString(),m_pAppSettings->value("QSpot/lastfmPwd","").toString());
-    }
-
-    //hide coverart state
-    if(m_pAppSettings->value("QSpot/HideCoverart",HIDE_COVERART_DEFAULT).toInt())
-    {
-        m_pQueueView->setHideCoverart(true);
-    }
-    else
-    {
-         m_pQueueView->setHideCoverart(false);
-    }
-
+    updateSettings(); //set application-related settings
 }
 
 void MainWindow::setDisplayOrientation(qint32 orientation)
@@ -764,6 +725,10 @@ void MainWindow::OnMainMenuAction(QAction* action)
     { //display the app About dialog
         m_AboutDlg.exec();
     }
+    else if(action->text()==tr("Log Out"))
+    { //log out the current user (and forget saved credentials)
+        logout();
+    }
 }
 
 
@@ -965,15 +930,7 @@ void MainWindow::OnLoggedOut()
     if(m_reConnectReq)
     {
         qDebug() << "Logged out, reconnecting to Spotify..";
-        err = m_pSession->reconnect(); //try to re-connect to Spotify using current session credentials
-        if(err.isError())
-        {//some error occured
-#ifdef Q_WS_MAEMO_5
-            QMaemo5InformationBox::information(this,tr("Failed to re-authenticate with Spotify"));
-#else
-            Banner::information(this,tr("Failed to re-authenticate with Spotify."));
-#endif
-        }
+        m_pSession->relogin(); //try to re-connect to Spotify using current session credentials
     }
 }
 
