@@ -50,7 +50,7 @@
 
 //defines
 
-#define APP_VERSION "0.9.3-1" //application version string
+#define APP_VERSION "0.9.9-1" //application version string
 
 class MainWindow : public QMainWindow
 {
@@ -64,6 +64,7 @@ public:
 protected:
 
     void keyPressEvent(QKeyEvent *evt);
+    void closeEvent(QCloseEvent *);
 
 private:
 
@@ -155,6 +156,8 @@ private:
 
     void initAboutDialog(); //setup the application about dialog
 
+    void updateSettings();  //update / set application-related settings
+
     void setupInitialState(); //set up the app initial state (audio etc.)
 
     void setDisplayOrientation(qint32 orientation); //set the display orientation
@@ -166,7 +169,7 @@ private slots:
 
      void OnShowLogin();
      void OnHandleLoginType(); //slot for detecting / handling automatic / manual login to Spotify
-     void OnLoggedIn(Spotify::Error error);
+     void OnLoginResponse(Spotify::Error error);
      void OnLoggedOut();
      void OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists);
      void OnPlaylistActivated(QModelIndex index);
@@ -195,7 +198,7 @@ private slots:
      void OnHWZoomKeyPressed(quint32 keycode); //notification that HW zoom key has been pressed
 #endif
      void OnSpotifyReconnectRequired(); //notification that current connection state has changed, and it is required to reconnect to the Spotify backend
-     void OnSpotifyLogin(const QString& strUserID, const QString& strPassword); //slot for handling login to the Spotify backend service
+     void OnSpotifyLogin(const QString& strUserID, const QString& strPassword, bool saveCredentials); //slot for handling login to the Spotify backend service
 
 signals:
 
