@@ -12,7 +12,7 @@ namespace Spotify
         Q_OBJECT
 
         public:
-        Playlist( sp_playlist* playlist = 0, QObject* parent = 0 );
+        Playlist(sp_session* session, sp_playlist* playlist = 0, QObject* parent = 0 );
             ~Playlist();
 
             QString getName() const { return m_name; }
@@ -34,6 +34,7 @@ namespace Spotify
             void stateChanged();
 
         private:
+            sp_session* m_session;
             sp_playlist* m_playlist;
             int m_position;
             QString m_name;
