@@ -1,6 +1,7 @@
 #ifndef SPOTIFYSESSION_H
 #define SPOTIFYSESSION_H
-#include <spotify/api.h>
+
+#include <libspotify/api.h>
 #include <QMetaType>
 #include <QList>
 #include <QImage>
@@ -39,6 +40,8 @@ namespace Spotify
 
             void initAudio(); //init the audio / playback thread
 
+            void setPreferredBitrate(const sp_bitrate& bitrate); //set preferred audio playback bitrate
+
             bool playlistLoadingInProgress(); //returns true in case playlist loading (getPlaylists) is currently in progress
 
             void stopPlaylistLoading(); //request to stop the playlist loading (getPlaylists).
@@ -65,9 +68,8 @@ namespace Spotify
 
             void resetPlaybackMembers();  //reset the playback related instance members (and removes any pending events from the playback thread)
 
-            QString getUserID(); //Returns current UserID for the session
-
-            QString getUserPwd(); //Returns current password for the session
+            QString getRememberedUser(); //Returns remembered UserID for the session
+            QString getUserPwd(); //Returns remembered password for the session
 
             /**
              * Pointer to the Session object. Used to map
@@ -100,15 +102,15 @@ namespace Spotify
              * Logs a user in to spotify.
              * @param username Username
              * @param password Password
-             * @return Error
+             * @param storeCredentals Whether user credentials should be remembered
              */
-            Spotify::Error login( QString username, QString password );
+            void login( QString username, QString password, bool storeCredentials = false);
 
             /**
-             * Reconnects / re-logins current user to Spotify. Used in case network connection etc. is temporarily lost, and reconnect is required.
-             * @return Error
+             * Reconnects / re-logins current user to Spotify. Used in case network connection etc. is temporarily lost, and reconnect is required
+             * Returns SP_ERROR_OK on success; otherwise error code is set.
              */
-            Spotify::Error reconnect();
+            Spotify::Error relogin();
 
             /**
              * Load a track
@@ -125,19 +127,18 @@ namespace Spotify
             /**
              * Seek to a given position in the stream.
              * @param pos Position to seek to (in msecs).
-             * @return Error
              */
-            Spotify::Error seek( qint32 pos );
+            void seek( qint32 pos );
 
             /**
              * Stop playback.
              */
-            Spotify::Error stop();
+            void stop();
 
             /**
-             * Toggle music delivery (i.e., buffering) pause from Spotify.
+             * Toggle music delivery (i.e., buffering) pause /resume from Spotify.
              */
-            Spotify::Error pauseResumeBuffering();
+            void pauseResumeBuffering();
 
             /**
              * Toggle playback pause / resume (e.g, stop / continue writing data to PulseAudio).
@@ -158,21 +159,15 @@ namespace Spotify
              * Request to load image (identified by imageID) from the Spotify backend
              * @param imageID ID of the image to be loaded.
              * @param Pointer to Spotify::ImageContainer instance for storing the loaded image
-             * @return Spotify::Error
+             * @return bool
              */
-            Spotify::Error loadImage(const byte* imageID, Spotify::ImageContainer* pContainer);
+            bool loadImage(const byte* imageID, Spotify::ImageContainer* pContainer);
 
             /**
              * Get the collection of playlists.
              */
             Spotify::Error getPlaylists();
 
-            /**
-             * Get / update the collection of tracks for specified playlist.
-             */
-            Spotify::Error getPlaylistTracks(Spotify::Playlist* pPlaylist);
-
-
             /**
              * Add a new playlist to the playlist container by name.
              * @param name Name of the new playlist.
@@ -508,7 +503,6 @@ namespace Spotify
 
             QTimer *m_pProcEvtTimer;
 
-
             /**
              * Audio playback thread
              */
