@@ -20,7 +20,7 @@ namespace Spotify
             Spotify::Track* track = m_tracks.at(i);
             if( !track->isLoaded() )
             {
-                qDebug() << "Attempting to load unloaded track from track collection ";
+               // qDebug() << "Attempting to load unloaded track from track collection ";
                 track->load();
             }
         }
